@@ -3,10 +3,12 @@ require("shiny", quietly = TRUE, character.only = TRUE)
 shiny_app <- shinyApp(
   ui = fluidPage(
     "Eval JS",
-    tags$script("
+    tags$script(
+      "
       var test_value = 42;
       var test_string = 'Hello world!';
-    "),
+    "
+    ),
     verbatimTextOutput("txt")
   ),
   server = function(input, output) {
@@ -18,7 +20,6 @@ shiny_app <- shinyApp(
 )
 
 
-
 test_that("Duplicate input ids are found", {
   app <- AppDriver$new(shiny_app)
 
