@@ -1,6 +1,4 @@
-
 test_that("Url Class behaves as expected", {
-
   expect_url <- function(url, expected_url) {
     expect_equal(Url$new()$set(url)$get(), expected_url)
   }
@@ -15,11 +13,12 @@ test_that("Url Class behaves as expected", {
   expect_url("http://user@a.b.com/", "http://user@a.b.com/")
   expect_url("http://user:pass@a.b.com/", "http://user:pass@a.b.com/")
 
+  expect_url("http:/a.b.com/", "http://a.b.com/")
+
   # Malformed URLs, or non-http/https protocol
   expect_url_error <- function(url, ...) {
     expect_error(Url$new()$set(url), ...)
   }
-  expect_url_error("http:/a.b.com/", "url hostname")
   expect_warning(
     expect_url_error("http://a.b.com:12ab/", "url port")
   )
